@@ -1,4 +1,4 @@
-"disc.ew" <-
+`disc.ew` <-
 function(data, varcon)
 {
 #****************************************************
