@@ -1,4 +1,4 @@
-"disc2" <-
+`disc2` <-
 function (x,k) 
 {
 #****************************************
