@@ -1,4 +1,4 @@
-"finco" <-
+`finco` <-
 function(data, level)
 {
 # ***************************************************************
