@@ -1,4 +1,4 @@
-"near1" <-
+`near1` <-
 function(x, data)
 {
 #****************************************
