@@ -1,4 +1,4 @@
-"signorm" <-
+`signorm` <-
 function (data) 
 {
 #***********************************************
